#!/bin/bash

# インストール先ディレクトリに必要なファイルをコピーし、権限等の設定を行います。
#  その後さらにDocuments/Read meを読んでWebShareの設定を行ってください。

# サイトを表示するHTTPサーバーapacheのグループ名です。
# このグループに必要なディレクトリとファイルの書き込み権限を与えます。
# これ以外の名前を使っている場合変更してください。
# apache2以外のHTTPサーバーで動作するかどうかは全くわかりません。（試してません。）
HTTP_SERVER_GROUP="apache"

# インストール先のディレクトリ(webshare表示ディレクトリ)をフルパスで指定してください。
# このディレクトリは既に存在してHTTPサーバーに書込権限がなければなりません。
# 既存のディレクトリの場合(アップデート等の場合)必要なファイルは上書きされます。
TGTDIR="/home/web/webshare"

# HTTPサーバーに書き込み権限が必要なディレクトリとファイルに設定するパーミッションです。
# HTTPサーバーをグループにするする場合の設定です。(必ずしも所有者でなくてかまいません。)
# レンタルサーバー等で上記の設定ができない場合、必要に応じて適宜パーミッションを設定してください。
WRITABLE_DIR_PERM=0775
WRITABLE_FILE_PERM=0664

# インストールログファイルの名前を変えたい場合は変えてください。
# ログファイルはインストールされたディレクトリ内に作られます。
LOGFILE="_INSTALL.log"

# 以上が設定項目。

# 上記の設定が終わったら、．．安全のためにこのままでは実行しません。
# 実行時に以下のexitを#でコメントアウトし（#exitとして）、実行した後、#を消して元に戻しておいてください。
########
exit;
########

##
## "WebShare" _INSTALL_SCRIPT.sh
##   Copyright by kiyoshi@kuragane.jp
##

# インストール用関数の定義
function filecopy()
{
  echo "-- Copying from $SRCDIR/$1 to" | tee -a "$TGTDIR/$LOGFILE"
  if [ -f "$SRCDIR/$1" ]
  then
    cd "$SRCDIR"
    echo "$1" | cpio -avdump "$TGTDIR" 2>&1 | tee -a "$TGTDIR/$LOGFILE"
  else
    echo "******** ERROR: Can't open file $SRCDIR/$1 ! ********" | tee -a "$TGTDIR/$LOGFILE"
  fi
  echo | tee -a "$TGTDIR/$LOGFILE"
}

function filecopy_if_noexists()
{
  if [ -f "$SRCDIR/$1" ]
  then
    if [ -f "$TGTDIR/$1" ]
    then
      echo "-- File $TGTDIR/$1 is already exists ! Pass copying." | tee -a "$TGTDIR/$LOGFILE"
    else
      echo "-- Copying from $SRCDIR/$1 to" | tee -a "$TGTDIR/$LOGFILE"
      cd "$SRCDIR"
      echo "$1" | cpio -avdump "$TGTDIR" 2>&1 | tee -a "$TGTDIR/$LOGFILE"
    fi
  else
    echo "******** ERROR: File $SRCDIR/$1 is not found ! ********" | tee -a "$TGTDIR/$LOGFILE"
  fi
  echo | tee -a "$TGTDIR/$LOGFILE"
}

function dircopy()
{
	if [ ! -d "$TGTDIR/$1" ]; then mkdir -m 0755 "$TGTDIR/$1"; fi
  if [ -d "$SRCDIR/$1" ]
  then
    echo "-- Copying files from $SRCDIR/$1 to $TGTDIR/$1" | tee -a "$TGTDIR/$LOGFILE"
    cd "$SRCDIR/$1"
    find . -print | cpio -avdump "$TGTDIR/$1" 2>&1 | sed "s/\/\.\//\//" | tee -a "$TGTDIR/$LOGFILE"
  else
    echo "******** ERROR: Can't open directory $SRCDIR/$1 ! ********" | tee -a "$TGTDIR/$LOGFILE"
  fi
  echo | tee -a "$TGTDIR/$LOGFILE"
}


# 以下、インストール実行文
cd `expr match "$0" "\(.*\)/[^/]*"`
SRCDIR=`pwd`
if [ ! -d "$TGTDIR" ]
then
  echo "******** ERROR: Install directory $TGTDIR does not exists ! ********"
  echo "******** ERROR: Install is Failed ! ********"
  exit
fi
cd "$TGTDIR"

echo "-- WebShare site install script $0 start." | tee "$TGTDIR/$LOGFILE"
date | tee -a "$TGTDIR/$LOGFILE"
echo | tee -a "$TGTDIR/$LOGFILE"

chmod $WRITABLE_DIR_PERM "$TGTDIR"

dircopy "admin"
chmod $WRITABLE_DIR_PERM "$TGTDIR/admin"

dircopy "cgi-bin"

mkdir -p "$TGTDIR/Corbeille"
chmod $WRITABLE_DIR_PERM "$TGTDIR/Corbeille"

mkdir -p "$TGTDIR/Documents"
chmod $WRITABLE_DIR_PERM "$TGTDIR/Documents"
dircopy "Documents/Read me"

mkdir -p "$TGTDIR/flux"
chmod $WRITABLE_DIR_PERM "$TGTDIR/flux"
filecopy "flux/index.php"

dircopy "lang"

mkdir -p "$TGTDIR/logs"
chmod $WRITABLE_DIR_PERM "$TGTDIR/logs"
filecopy_if_noexists "logs/.htaccess"
chmod $WRITABLE_FILE_PERM "$TGTDIR/logs/.htaccess"

dircopy "moteur"
chmod $WRITABLE_DIR_PERM "$TGTDIR/moteur"

dircopy "plugins"
chmod $WRITABLE_DIR_PERM "$TGTDIR/plugins"

dircopy "style"

mkdir -p "$TGTDIR/wspasswd"
chmod $WRITABLE_DIR_PERM "$TGTDIR/wspasswd"
filecopy_if_noexists "wspasswd/.htaccess"
chmod $WRITABLE_FILE_PERM "$TGTDIR/wspasswd/.htaccess"
echo "root:root" > "$TGTDIR/wspasswd/.htpasswd-DEFAULT"
chmod $WRITABLE_FILE_PERM "$TGTDIR/wspasswd/.htpasswd-DEFAULT"
if [ -f "$TGTDIR/wspasswd/.htpasswd" ]
then
  echo "-- File $TGTDIR/wspasswd/.htpasswd is already exists ! Pass copying." | tee -a "$TGTDIR/$LOGFILE"
else
  echo "-- Copying from $SRCDIR/wspasswd/.htpasswd-DEFAULT to $TGTDIR/wspasswd/.htpasswd" | tee -a "$TGTDIR/$LOGFILE"
	cp -p "$SRCDIR/wspasswd/.htpasswd-DEFAULT" "$TGTDIR/wspasswd/.htpasswd"
fi
chmod $WRITABLE_FILE_PERM "$TGTDIR/wspasswd/.htpasswd"
echo | tee -a "$TGTDIR/$LOGFILE"

if [ -f "$TGTDIR/wspasswd/conf.ini" ]
then
  echo "-- File $TGTDIR/wspasswd/conf.ini is already exists ! Pass copying." | tee -a "$TGTDIR/$LOGFILE"
else
  echo "-- Copying from $SRCDIR/wspasswd/conf.ini-DEFAULT to $TGTDIR/wspasswd/conf.ini" | tee -a "$TGTDIR/$LOGFILE"
	cp -p "$SRCDIR/wspasswd/conf.ini-DEFAULT" "$TGTDIR/wspasswd/conf.ini"
fi
chmod $WRITABLE_FILE_PERM "$TGTDIR/wspasswd/conf.ini"
filecopy "wspasswd/conf.ini-DEFAULT"
chmod $WRITABLE_FILE_PERM "$TGTDIR/wspasswd/conf.ini-DEFAULT"
echo | tee -a "$TGTDIR/$LOGFILE"

if [ -f "$TGTDIR/wspasswd/define.php" ]
then
  echo "-- File $TGTDIR/wspasswd/define.php is already exists ! Pass copying." | tee -a "$TGTDIR/$LOGFILE"
else
  echo "-- Copying from $SRCDIR/wspasswd/define.php-DEFAULT to $TGTDIR/wspasswd/define.php" | tee -a "$TGTDIR/$LOGFILE"
	cp -p "$SRCDIR/wspasswd/define.php-DEFAULT" "$TGTDIR/wspasswd/define.php"
fi
filecopy "wspasswd/define.php-DEFAULT"
echo | tee -a "$TGTDIR/$LOGFILE"

mkdir -p "$TGTDIR/wssite"
chmod $WRITABLE_DIR_PERM "$TGTDIR/wssite"

mkdir -p "$TGTDIR/wstemp"
chmod $WRITABLE_DIR_PERM "$TGTDIR/wstemp"

if [ -f "$TGTDIR/.htaccess" ]
then
  echo "-- File $TGTDIR/.htaccess is already exists ! Pass copying." | tee -a "$TGTDIR/$LOGFILE"
else
  echo "-- Copying from $SRCDIR/.htaccess-DEFAULT to $TGTDIR/.htaccess" | tee -a "$TGTDIR/$LOGFILE"
	cp -p "$SRCDIR/.htaccess-DEFAULT" "$TGTDIR/.htaccess"
fi
filecopy ".htaccess-DEFAULT"
filecopy "COPYING.txt"
filecopy "ident.php"
filecopy "iframe.php"
filecopy "index.php"
filecopy "indexldap.php"
filecopy "indexpublic.php"
filecopy "prive.php"
filecopy "public.php"
filecopy "README.txt"
filecopy "start.php"

#filecopy "_INSTALL_webshare.sh"

chgrp -R "$HTTP_SERVER_GROUP" "$TGTDIR"

echo "-- WebShare Site Install finished. Please check logfile $TGTDIR/$LOGFILE" | tee -a "$TGTDIR/$LOGFILE"
date | tee -a "$TGTDIR/$LOGFILE"
echo | tee -a "$TGTDIR/$LOGFILE"

exit
